summaryrefslogtreecommitdiffstats
path: root/juk/keydialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/keydialog.h')
-rw-r--r--juk/keydialog.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/juk/keydialog.h b/juk/keydialog.h
index 13801ee1..83c14d9d 100644
--- a/juk/keydialog.h
+++ b/juk/keydialog.h
@@ -26,12 +26,13 @@
class KeyDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a KeyDialog called @p name as a child of @p parent.
*/
- KeyDialog(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0, const char* name = 0);
+ KeyDialog(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *tqparent = 0, const char* name = 0);
/**
* Destructor. Deletes all resources used by a KeyDialog object.
@@ -43,7 +44,7 @@ public:
* accelerators and actions. It behaves essentially like the functions
* in KKeyDialog.
*/
- static int configure(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0);
+ static int configure(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *tqparent = 0);
/**
* This is a member function, provided to create a global accelerator with
@@ -26,12 +26,13 @@
public:
/**
- * Constructs a KeyDialog called @p name as a child of @p parent.
+ * Constructs a KeyDialog called @p name as a child of @p tqparent.
*/